## 

### 

#### Free software, free hardware, and other things

Richard Stallman

RoomTBA

Preceded by a welcome address from John Sullivan, FSF executive
director.

#### Federation and GNU

[Christopher Webber][webber]

[webber]: http://dustycloud.org

Room 32-123

The effort to re-decentralize the web has been under way for a number
of years, but what's really happening under the hood? Various projects
like Diaspora, GNU social, [GNU MediaGoblin][gmg-home], Friendica Red, and Pump.IO
all exist, but not all these projects can talk to each other. How can
we fix that? A demo of PyPump will be given, as well as a rundown on
the progress of the W3C Social Working Group.

[gmg-home]: http://mediagoblin.org/

#### Dr. Hyde and Mr. Jekyll: advocating for free software in nonfree academic contexts

ginger coons

Room 32-141

What if the classic horror trope of the good doctor who becomes a
monster at night were reversed? Instead of the good Dr. Jekyll
transforming into the rampaging Mr. Hyde, advocates of free who work
in nonfree environments can feel as if they only get to put on their
altruistic persona at night. For academics advocating free software
and free culture in particular, libre ethics are often at odds with
both administrative structures and expected teaching outcomes. This
session explores the struggles of advocating free in both research and
teaching.

#### TAFTA, CETA, TISA: traps and threats to Free Software Everywhere

[Marianne Corvellec][corvellec], [Jonathan Le Lous][lous]

Room 32-155

TAFTA, CETA, and TISA are far-reaching trade agreements posing major
threats to online freedom and creating legal uncertainty for all
Internet players. They set forth an ever stronger protection of
copyright and patents. They 'recycle' the most toxic parts of ACTA,
the anti-counterfeiting trade agreement which was rejected
in 2012. The presentation focuses on the software aspects of TAFTA,
CETA, TISA. We will call for action against these global treaty
projects and offer alternative proposals, which favour Free Software
Everywhere.

[corvellec]: http://libreplanet.org/2015/program/speakers.html#corvellec
[lous]: http://libreplanet.org/2015/program/speakers.html#le-lous

#### Let's encrypt!

Seth Schoen

Room 32-123

This year a robotic certificate authority will start issuing
publicly-trusted certificates, at no charge, by the millions. Called
Let's Encrypt, this CA is an initiative of several organizations. Our
free software and protocol will let sysadmins run a single command to
turn on HTTPS on their servers in about a minute, helping eliminate
obstacles to activating encryption for every Web server. I'll describe
how it all works and give a demo. We need lots of testing and
integration help!

#### Attribution revolution -- turning copyright upside-down

Jonas Öberg

Room 32-141

Reusing works licensed under free licenses seems pretty simple, but it
can often be quite time consuming. One image or a few lines of source
code might be okay, but keeping track of the license and attribution
of a thousand different pieces, or when quoting from massive data sets
such as Wikipedia? Whoah! Don’t we have computers to do that for us!?
We do, but there’s no widespread support for including licensing or
author information when sharing or reusing digital works. This session
will discuss how this should work in a free knowledge environment, and
could it be that many problems regarding copyright and "piracy" in our
digital society could be solved with free software?

In order to relate effectively to the digital works we see online,
attribution (who made or built something) matters. Proper attribution
is the start of being able to explore digital works online in their
right context. This talk will focus on the philosophical background of
why attribution matters, the benefits that free software can bring to
the way we work with pieces of art (lolcats and Shakespeare alike),
and where we're heading in the future.


#### Access without empowerment

Benjamin Mako Hill

Room 32-123

The free software movement has twin goals: promoting access to
software through users' freedom to share, and empowering users by
giving them control over their technology. For all our movement's
success, we have been much more successful at the former. I will use
data from free software and from several related movements to explain
why promoting empowerment is systematically more difficult than
promoting access and I will explore how our movement might address the
second challenge in the future.

#### Fork and ignore: fighting a GPL violation by coding instead

Bradley Kuhn

Room 32-123

Typically, GPL enforcement activity involves copyright infringement
actions which compel license violators to correct errors in their GPL
compliance, defending the policy goals of the GPL: the rights of
developers and users to copy, share, modify and redistribute.

While traditional enforcement is often undeniably necessary for
embedded electronics products, novel approaches to GPL violations are
often possible and even superior for more traditional software
distributions.

Recently, Software Freedom Conservancy engaged in an enforcement
action whereby, rather than fight the violator in court, we instead
provided resources and assistance to a vetted GPL-compliant fork of a
violating codebase.

This talk discusses which scenarios make this remedy optimal and the
lessons learned. The talk includes some licensing and technical
content about vetting the licensing information of codebases.

#### Who did this? Just wait until your father gets home

Ken Starks

Room 32-141

What's going on in here? Computer parts laying all over the
place... screws and ribbon cables scattered cross heaven's half
acre. And who left this power supply in the refrigerator? Is that your
dad's new impact drive? Don't you dare let me get up in the middle of
the night and step on that motherboard in my bare feet. Just what in
the name of Michael Dell is going on here?
